---
title: Why Quasar?
desc: What Quasar is and how it can considerably reduce your development time and costs.
---

Because it saves development costs drastically. Only Quasar can do:

<script doc>
import IntroductionVideo from './IntroductionVideo.vue'
</script>

<IntroductionVideo />

Also because:

* It's based on Vue.js
* You get a state-of-the-art UI (that follows Material Guidelines) for your **websites** and **apps** out of the box
* Best support for desktop and **mobile browsers** (including iOS Safari!) out of the box
* Best-in-class support for each build mode (SPA, SSR, PWA, Mobile app, Desktop app & Browser Extension) and the best developer experience through a tight integration with our own CLI
* It's easily customizable (CSS) and extendable (JS)
* It's the most performance-focused framework
* It's tree-shakable automatically
* Incredible community on our Forum and Discord chat
* Has a regular release cycle inclusive of new features
* Gets quick fixes and listens to the community's requests
* Handles the whole development experience (including even creating your app's icons and splash screens)

Worried about bloat? You shouldn't be. If you only want to build a website, Quasar will only build the code required for a website, with nothing else. Same goes for the other build modes.

## What is Quasar?
Quasar (pronounced `/ˈkweɪ.zɑɹ/`) is an MIT licensed open-source Vue.js based framework, which allows you as a web developer to quickly create responsive++ websites/apps in many flavours:
* SPAs (Single Page App)
* SSR (Server-side Rendered App) (+ optional PWA client takeover)
* PWAs (Progressive Web App)
* BEX (Browser Extension)
* Mobile Apps (Android, iOS, …) through Cordova or Capacitor
* Multi-platform Desktop Apps (using Electron)

Quasar's motto is: **write code once and simultaneously deploy it** as a website, a Mobile App and/or an Electron App. Yes, one codebase for all of them, helping you develop an app in record time by using a state-of-the-art CLI and backed by best-practice, blazing fast Quasar web components.

When using Quasar, you won't need additional heavy libraries like Hammer.js, Moment.js or Bootstrap. It's got those needs covered internally, and all with a small footprint!

## What else you got?
Because of the simplicity and power offered to you out of the box, Quasar, with its CLI, is packed full of features, all built to make your developer life easier.

::: tip Food for thought
Quasar is looking into the future and sets its own high and modern standards. And yes, in order to make progress in web development, we need to break the current establishment. Otherwise, we’d all continue to write websites in cgi-bin / perl today too, because many years ago that’s what developers were accustomed to. However, what most developers are accustomed to at one point in time doesn’t actually mean it’s the best solution or the “definite” solution, and Quasar will never bend into choosing what we believe is not the optimal path to high-quality work, not even over money.
<br><br>

*What we want to achieve with Quasar is to raise the bar for web development as a whole. Make it go forward, evolve. Change minds. Point out when there’s a better alternative.*
:::

Below is a non-exhaustive list of Quasar's great aspects and features.

#### All Platforms in One Go
One authoritative source of code for all platforms, simultaneously: responsive desktop/mobile websites (SPA, SSR + SPA client takeover, SSR + PWA client takeover), PWAs (Progressive Web Apps), mobile apps (that look native) and multi-platform desktop apps (through Electron).

#### The largest set of top-class, fast and responsive web components
There’s a component for almost every web development need within Quasar. Each of Quasar's components is carefully crafted to offer you the best possible experience for your users. Quasar is **designed with performance & responsiveness in mind** – so the overhead of using Quasar is barely noticeable. This attention to performance and good design is something that gives us special pride.

#### Best practices integrated by default
Quasar was also built to encourage developers to follow web development best practices. To do this, Quasar is packed full of great features out of the box - **with no configuration needed**.

#### App Extensions support
Quasar App Extensions are a way to painlessly inject complicated (or simple) setups into your websites/apps. They're also a way for our big community to contribute and help you get up to speed even faster. **The patterns for development literally open the floodgates to making Quasar one of the most extensible and powerful frameworks out there** - limited only by your imagination and innovation.

#### Full RTL Support
RTL (right to left) support for both Quasar components & the developer’s own code. Developer-written website/app CSS code gets automatically converted to RTL if an RTL language pack is used.

#### Progressively migrate your existing project
Quasar offers a UMD (Unified Module Definition) version, which means developers can add a CSS and JS HTML tag into their existing project and they’re ready to use it. No build step is required.

#### Focus on your features, not the boilerplating
The top-class project initialization with Quasar CLI makes getting started very easy for you as a developer. You can turn your idea into reality in record time. In other words, Quasar does the heavy lifting for you, so you are free to focus on your features and not on boilerplate.

#### Automated testing & audit
Quasar projects have the ability to add Unit and End-to-End testing harnesses out of the box, as well as an ever-growing suite of product quality and security auditing tools. All this to ensure that your websites/apps have the highest quality possible.

#### Awesome ever-growing community
When developers encounter a problem they can’t solve, they can visit the Quasar [forum](https://forum.quasar.dev/) or our [Discord chat server](https://chat.quasar.dev). The community is always there to help you. You can also get updates on new versions and features by following us on [Twitter](https://twitter.quasar.dev). You can also get special service as a [backer/sponsor](https://donate.quasar.dev) and help make sure Quasar stays relevant for you in the future too!

#### A wide range of platform support
Google Chrome, Firefox, Edge, Safari, Opera, iOS, Android, MacOS, Linux, Windows.

#### Quasar Language Packs
Quasar comes equipped with over 40 language packs out of the box. On top of that, if your language pack is missing, it takes just 5 minutes to add it.

#### Great documentation
And finally, it’s worth mentioning the significant amount of time taken to write great, bloat-free, focused and complete documentation so that developers can quickly pick up Quasar. We put special effort into our documentation to make sure there is no confusion.

## Get started in under a minute
Having said this, let's [get started](/start)! You'll be running a website or app in under a minute.
